#include <QDesktopServices>
#include <QUrl>
#include "symfonieaboutdialog.h"
#include "ui_symfonieaboutdialog.h"

SymfonieAboutDialog::SymfonieAboutDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SymfonieAboutDialog)
{
    ui->setupUi(this);
     this->setAttribute(Qt::WA_DeleteOnClose, true);
    this->setWindowTitle(tr("About symfonie"));
    connect(this->ui->btnHomePage, SIGNAL(released()), this, SLOT(openHomeUrlSlot()));
}



SymfonieAboutDialog::~SymfonieAboutDialog()
{
    delete ui;
}

void SymfonieAboutDialog::openHomeUrlSlot(){
     QDesktopServices::openUrl(QUrl("http://thecodecentral.com/symfonie", QUrl::TolerantMode));
}

void SymfonieAboutDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:

        break;
    }
}

